/* ---------------------------------------------------------------------------------------------------------------------------- */
/* CREATE SERVER LOGINS TO SERVER INSTANCE <SERVERNAME>\<INSTANCENAME>, AND ASSIGN PERMISSIONS VIA SERVER ROLE */
/* REPEAT THE SECTION BELOW FOR EACH SERVER LOGIN */
/* ---------------------------------------------------------------------------------------------------------------------------- */

/* Security Architecture:  
	https://learn.microsoft.com/en-us/sql/relational-databases/security/authentication-access/getting-started-with-database-engine-permissions?view=sql-server-ver16
	https://www.mssqltips.com/sqlservertip/2699/sql-server-user-defined-server-roles/
	https://learn.microsoft.com/en-us/sql/t-sql/statements/create-login-transact-sql?view=sql-server-ver16 */

USE master;
GO
/* Grant EXECUTE to OLEDB_Provider */
GRANT EXECUTE ON SYS.XP_PROP_OLEDB_PROVIDER TO [Public];
GO

USE master;	-- For Server Level, always master DB
GO


/* --------------------------------------------------------------------------------------------------------------------- */
/* FOR EACH SQLSERVER USER CREATE A SERVER LOGIN */
/* Set Up Server Login OpISuper */
/* REPEAT THE SECTION BELOW FOR EACH SQLSERVER LOGIN */
DECLARE	@OpI_LoginName NVARCHAR(30) = NULL
DECLARE	@activeNow NVARCHAR(6) = N'No'
DECLARE @replaceNow NVARCHAR(3) = N'No'
DECLARE	@OpI_LoginPassword NVARCHAR(30) = N'abcd%12'
DECLARE @mustChange NVARCHAR(3) = N'No'					-- Yes or No
DECLARE	@passwordExpires NVARCHAR(3) = N'OFF'			-- ON or OFF
DECLARE	@checkPolicy NVARCHAR(3) = N'OFF'				-- ON or OFF
DECLARE	@OpI_LoginWindows NVARCHAR(9) = NULL
DECLARE	@roleName NVARCHAR(max) = NULL
DECLARE	@with NVARCHAR(max) = NULL
DECLARE	@query NVARCHAR(max) = NULL

SET		@OpI_LoginName=N'OpISuper';
SET		@activeNow = N'Yes'
SET		@replaceNow = N'No'
SET		@OpI_LoginWindows=N'SQLServer';					-- WINDOWS or SQLServer
SET			@OpI_LoginPassword=N'abcd%12';				-- For SQLServer; WINDOWS Login takes from Windows security
SET			@mustChange = N'No'							-- For SQLServer; Yes or No
SET			@passwordExpires = N'OFF'					-- For SQLServer; ON or OFF
SET			@checkPolicy = N'OFF'						-- For SQLServer; ON or OFF
SET		@roleName = N'OpIRoleSvrSuper'					-- OpIRoleSvrSuper, OpIRoleSvrManager, OpIRoleSvrDataOwner, OpIRoleSvrClient

IF @activeNow = N'Yes'
BEGIN
	IF @replaceNow = N'Yes' 
	BEGIN 
		SET @query = 
		N'IF EXISTS (SELECT[sys].[sql_logins].[name], [sys].[sql_logins].[type] '
		+ N'	FROM [sys].[sql_logins]'
		+ N'	WHERE [type] IN (N''U'', N''S'') AND [name] = ''' + @OpI_LoginName + N''') '
		+ N'DROP LOGIN ' + @OpI_LoginName + N';';  EXEC sp_executesql @query;
	END

	SET	@with = NULL
	IF	(@OpI_LoginWindows=N'SQLServer')
	BEGIN
		SET @with = ' WITH PASSWORD = N''' + @OpI_LoginPassword + N''''
		IF @mustChange = 'Yes' SET @with = @with + ', MUSTCHANGE'
		SET @with = @with + N', CHECK_EXPIRATION = ' + @passwordExpires
		SET @with = @with + N', CHECK_POLICY = ' + @checkPolicy
	END
	IF	( @OpI_LoginWindows = N'WINDOWS' )	
		SET @with=N' FROM WINDOWS'

	IF NOT EXISTS (SELECT [sys].[sql_logins].[name], [sys].[sql_logins].[type] 
		FROM [sys].[sql_logins] 
		WHERE [type] IN (N'U', N'S') AND [name] = @OpI_LoginName) 
	BEGIN 
		SET @query = N'CREATE LOGIN  [' + @OpI_LoginName + ']' + @with +  N';'; EXEC sp_executesql @query;
	END;

	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;

	/* Add membership to OpI Fixed-Role Membership Role if it exists */
	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N'Fixed' + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N'Fixed' + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;
END
GO


/* --------------------------------------------------------------------------------------------------------------------- */
/* FOR EACH SQLSERVER USER CREATE A SERVER LOGIN */
/* Set Up Server Login OpIManager */
/* REPEAT THE SECTION BELOW FOR EACH SQLSERVER LOGIN */
DECLARE	@OpI_LoginName NVARCHAR(30) = NULL
DECLARE	@activeNow NVARCHAR(6) = N'No'
DECLARE @replaceNow NVARCHAR(3) = N'No'
DECLARE	@OpI_LoginPassword NVARCHAR(30) = N'abcd%12'
DECLARE @mustChange NVARCHAR(3) = N'No'					-- Yes or No
DECLARE	@passwordExpires NVARCHAR(3) = N'OFF'			-- ON or OFF
DECLARE	@checkPolicy NVARCHAR(3) = N'OFF'				-- ON or OFF
DECLARE	@OpI_LoginWindows NVARCHAR(9) = NULL
DECLARE	@roleName NVARCHAR(max) = NULL
DECLARE	@with NVARCHAR(max) = NULL
DECLARE	@query NVARCHAR(max) = NULL

SET		@OpI_LoginName=N'OpIManager';
SET		@activeNow = N'Yes'
SET		@replaceNow = N'No'
SET		@OpI_LoginWindows=N'SQLServer';					-- WINDOWS or SQLServer
SET			@OpI_LoginPassword=N'abcd%12';				-- For SQLServer; WINDOWS Login takes from Windows security
SET			@mustChange = N'No'							-- For SQLServer; Yes or No
SET			@passwordExpires = N'OFF'					-- For SQLServer; ON or OFF
SET			@checkPolicy = N'OFF'						-- For SQLServer; ON or OFF
SET		@roleName = N'OpIRoleSvrManager'				-- OpIRoleSvrSuper, OpIRoleSvrManager, OpIRoleSvrDataOwner, OpIRoleSvrClient

IF @activeNow = N'Yes'
BEGIN
	IF @replaceNow = N'Yes' 
	BEGIN 
		SET @query = 
		N'IF EXISTS (SELECT[sys].[sql_logins].[name], [sys].[sql_logins].[type] '
		+ N'	FROM [sys].[sql_logins]'
		+ N'	WHERE [type] IN (N''U'', N''S'') AND [name] = ''' + @OpI_LoginName + N''') '
		+ N'DROP LOGIN ' + @OpI_LoginName + N';';  EXEC sp_executesql @query;
	END

	SET	@with = NULL
	IF	(@OpI_LoginWindows=N'SQLServer')
	BEGIN
		SET @with = ' WITH PASSWORD = N''' + @OpI_LoginPassword + N''''
		IF @mustChange = 'Yes' SET @with = @with + ', MUSTCHANGE'
		SET @with = @with + N', CHECK_EXPIRATION = ' + @passwordExpires
		SET @with = @with + N', CHECK_POLICY = ' + @checkPolicy
	END
	IF	( @OpI_LoginWindows = N'WINDOWS' )	
		SET @with=N' FROM WINDOWS'

	IF NOT EXISTS (SELECT [sys].[sql_logins].[name], [sys].[sql_logins].[type] 
		FROM [sys].[sql_logins] 
		WHERE [type] IN (N'U', N'S') AND [name] = @OpI_LoginName) 
	BEGIN 
		SET @query = N'CREATE LOGIN  [' + @OpI_LoginName + ']' + @with +  N';'; EXEC sp_executesql @query;
	END;

	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;

	/* Add membership to OpI Fixed-Role Membership Role if it exists */
	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N'Fixed' + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N'Fixed' + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;
END
GO


/* --------------------------------------------------------------------------------------------------------------------- */
/* FOR EACH SQLSERVER USER CREATE A SERVER LOGIN */
/* Set Up Server Login OpIDataOwner */
/* REPEAT THE SECTION BELOW FOR EACH SQLSERVER LOGIN */
DECLARE	@OpI_LoginName NVARCHAR(30) = NULL
DECLARE	@activeNow NVARCHAR(6) = N'No'
DECLARE @replaceNow NVARCHAR(3) = N'No'
DECLARE	@OpI_LoginPassword NVARCHAR(30) = N'abcd%12'
DECLARE @mustChange NVARCHAR(3) = N'No'					-- Yes or No
DECLARE	@passwordExpires NVARCHAR(3) = N'OFF'			-- ON or OFF
DECLARE	@checkPolicy NVARCHAR(3) = N'OFF'				-- ON or OFF
DECLARE	@OpI_LoginWindows NVARCHAR(9) = NULL
DECLARE	@roleName NVARCHAR(max) = NULL
DECLARE	@with NVARCHAR(max) = NULL
DECLARE	@query NVARCHAR(max) = NULL

SET		@OpI_LoginName=N'OpIDataOwner';
SET		@activeNow = N'Yes'
SET		@replaceNow = N'No'
SET		@OpI_LoginWindows=N'SQLServer';					-- WINDOWS or SQLServer
SET			@OpI_LoginPassword=N'abcd%12';				-- For SQLServer; WINDOWS Login takes from Windows security
SET			@mustChange = N'No'							-- For SQLServer; Yes or No
SET			@passwordExpires = N'OFF'					-- For SQLServer; ON or OFF
SET			@checkPolicy = N'OFF'						-- For SQLServer; ON or OFF
SET		@roleName = N'OpIRoleSvrDataOwner'				-- OpIRoleSvrSuper, OpIRoleSvrManager, OpIRoleSvrDataOwner, OpIRoleSvrClient

IF @activeNow = N'Yes'
BEGIN
	IF @replaceNow = N'Yes' 
	BEGIN 
		SET @query = 
		N'IF EXISTS (SELECT[sys].[sql_logins].[name], [sys].[sql_logins].[type] '
		+ N'	FROM [sys].[sql_logins]'
		+ N'	WHERE [type] IN (N''U'', N''S'') AND [name] = ''' + @OpI_LoginName + N''') '
		+ N'DROP LOGIN ' + @OpI_LoginName + N';';  EXEC sp_executesql @query;
	END

	SET	@with = NULL
	IF	(@OpI_LoginWindows=N'SQLServer')
	BEGIN
		SET @with = ' WITH PASSWORD = N''' + @OpI_LoginPassword + N''''
		IF @mustChange = 'Yes' SET @with = @with + ', MUSTCHANGE'
		SET @with = @with + N', CHECK_EXPIRATION = ' + @passwordExpires
		SET @with = @with + N', CHECK_POLICY = ' + @checkPolicy
	END
	IF	( @OpI_LoginWindows = N'WINDOWS' )	
		SET @with=N' FROM WINDOWS'

	IF NOT EXISTS (SELECT [sys].[sql_logins].[name], [sys].[sql_logins].[type] 
		FROM [sys].[sql_logins] 
		WHERE [type] IN (N'U', N'S') AND [name] = @OpI_LoginName) 
	BEGIN 
		SET @query = N'CREATE LOGIN  [' + @OpI_LoginName + ']' + @with +  N';'; EXEC sp_executesql @query;
	END;

	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;

	/* Add membership to OpI Fixed-Role Membership Role if it exists */
	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N'Fixed' + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N'Fixed' + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;
END
GO


/* --------------------------------------------------------------------------------------------------------------------- */
/* FOR EACH SQLSERVER USER CREATE A SERVER LOGIN */
/* Set Up Server Login OpIClient */
/* REPEAT THE SECTION BELOW FOR EACH SQLSERVER LOGIN */
DECLARE	@OpI_LoginName NVARCHAR(30) = NULL
DECLARE	@activeNow NVARCHAR(6) = N'No'
DECLARE @replaceNow NVARCHAR(3) = N'No'
DECLARE	@OpI_LoginPassword NVARCHAR(30) = N'abcd%12'
DECLARE @mustChange NVARCHAR(3) = N'No'					-- Yes or No
DECLARE	@passwordExpires NVARCHAR(3) = N'OFF'			-- ON or OFF
DECLARE	@checkPolicy NVARCHAR(3) = N'OFF'				-- ON or OFF
DECLARE	@OpI_LoginWindows NVARCHAR(9) = NULL
DECLARE	@roleName NVARCHAR(max) = NULL
DECLARE	@with NVARCHAR(max) = NULL
DECLARE	@query NVARCHAR(max) = NULL

SET		@OpI_LoginName=N'OpIClient';
SET		@activeNow = N'Yes'
SET		@replaceNow = N'No'
SET		@OpI_LoginWindows=N'SQLServer';					-- WINDOWS or SQLServer
SET			@OpI_LoginPassword=N'abcd%12';				-- For SQLServer; WINDOWS Login takes from Windows security
SET			@mustChange = N'No'							-- For SQLServer; Yes or No
SET			@passwordExpires = N'OFF'					-- For SQLServer; ON or OFF
SET			@checkPolicy = N'OFF'						-- For SQLServer; ON or OFF
SET		@roleName = N'OpIRoleSvrClient'					-- OpIRoleSvrSuper, OpIRoleSvrManager, OpIRoleSvrDataOwner, OpIRoleSvrClient

IF @activeNow = N'Yes'
BEGIN
	IF @replaceNow = N'Yes' 
	BEGIN 
		SET @query = 
		N'IF EXISTS (SELECT[sys].[sql_logins].[name], [sys].[sql_logins].[type] '
		+ N'	FROM [sys].[sql_logins]'
		+ N'	WHERE [type] IN (N''U'', N''S'') AND [name] = ''' + @OpI_LoginName + N''') '
		+ N'DROP LOGIN ' + @OpI_LoginName + N';';  EXEC sp_executesql @query;
	END

	SET	@with = NULL
	IF	(@OpI_LoginWindows=N'SQLServer')
	BEGIN
		SET @with = ' WITH PASSWORD = N''' + @OpI_LoginPassword + N''''
		IF @mustChange = 'Yes' SET @with = @with + ', MUSTCHANGE'
		SET @with = @with + N', CHECK_EXPIRATION = ' + @passwordExpires
		SET @with = @with + N', CHECK_POLICY = ' + @checkPolicy
	END
	IF	( @OpI_LoginWindows = N'WINDOWS' )	
		SET @with=N' FROM WINDOWS'

	IF NOT EXISTS (SELECT [sys].[sql_logins].[name], [sys].[sql_logins].[type] 
		FROM [sys].[sql_logins] 
		WHERE [type] IN (N'U', N'S') AND [name] = @OpI_LoginName) 
	BEGIN 
		SET @query = N'CREATE LOGIN  [' + @OpI_LoginName + ']' + @with +  N';'; EXEC sp_executesql @query;
	END;

	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;

	/* Add membership to OpI Fixed-Role Membership Role if it exists */
	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N'Fixed' + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N'Fixed' + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;
END
GO


/* --------------------------------------------------------------------------------------------------------------------- */
/* FOR EACH SQLSERVER USER CREATE A SERVER LOGIN */
/* Set Up Server Login ProgramManagement */
/* REPEAT THE SECTION BELOW FOR EACH SQLSERVER LOGIN */
DECLARE	@OpI_LoginName NVARCHAR(30) = NULL
DECLARE	@activeNow NVARCHAR(6) = N'No'
DECLARE @replaceNow NVARCHAR(3) = N'No'
DECLARE	@OpI_LoginPassword NVARCHAR(30) = N'abcd%12'
DECLARE @mustChange NVARCHAR(3) = N'No'					-- Yes or No
DECLARE	@passwordExpires NVARCHAR(3) = N'OFF'			-- ON or OFF
DECLARE	@checkPolicy NVARCHAR(3) = N'OFF'				-- ON or OFF
DECLARE	@OpI_LoginWindows NVARCHAR(9) = NULL
DECLARE	@roleName NVARCHAR(max) = NULL
DECLARE	@with NVARCHAR(max) = NULL
DECLARE	@query NVARCHAR(max) = NULL

SET		@OpI_LoginName=N'ProgramManagement';
SET		@activeNow = N'Yes'
SET		@replaceNow = N'No'
SET		@OpI_LoginWindows=N'SQLServer';					-- WINDOWS or SQLServer
SET			@OpI_LoginPassword=N'abcd%12';				-- For SQLServer; WINDOWS Login takes from Windows security
SET			@mustChange = N'No'							-- For SQLServer; Yes or No
SET			@passwordExpires = N'OFF'					-- For SQLServer; ON or OFF
SET			@checkPolicy = N'OFF'						-- For SQLServer; ON or OFF
SET		@roleName = N'OpIRoleSvrManager'				-- OpIRoleSvrSuper, OpIRoleSvrManager, OpIRoleSvrDataOwner, OpIRoleSvrClient

IF @activeNow = N'Yes'
BEGIN
	IF @replaceNow = N'Yes' 
	BEGIN 
		SET @query = 
		N'IF EXISTS (SELECT[sys].[sql_logins].[name], [sys].[sql_logins].[type] '
		+ N'	FROM [sys].[sql_logins]'
		+ N'	WHERE [type] IN (N''U'', N''S'') AND [name] = ''' + @OpI_LoginName + N''') '
		+ N'DROP LOGIN ' + @OpI_LoginName + N';';  EXEC sp_executesql @query;
	END

	SET	@with = NULL
	IF	(@OpI_LoginWindows=N'SQLServer')
	BEGIN
		SET @with = ' WITH PASSWORD = N''' + @OpI_LoginPassword + N''''
		IF @mustChange = 'Yes' SET @with = @with + ', MUSTCHANGE'
		SET @with = @with + N', CHECK_EXPIRATION = ' + @passwordExpires
		SET @with = @with + N', CHECK_POLICY = ' + @checkPolicy
	END
	IF	( @OpI_LoginWindows = N'WINDOWS' )	
		SET @with=N' FROM WINDOWS'

	IF NOT EXISTS (SELECT [sys].[sql_logins].[name], [sys].[sql_logins].[type] 
		FROM [sys].[sql_logins] 
		WHERE [type] IN (N'U', N'S') AND [name] = @OpI_LoginName) 
	BEGIN 
		SET @query = N'CREATE LOGIN  [' + @OpI_LoginName + ']' + @with +  N';'; EXEC sp_executesql @query;
	END;

	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;

	/* Add membership to OpI Fixed-Role Membership Role if it exists */
	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N'Fixed' + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N'Fixed' + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;
END
GO


/* --------------------------------------------------------------------------------------------------------------------- */
/* FOR EACH SQLSERVER USER CREATE A SERVER LOGIN */
/* Set Up Server Login ProgramManagement2 */
/* REPEAT THE SECTION BELOW FOR EACH SQLSERVER LOGIN */
DECLARE	@OpI_LoginName NVARCHAR(30) = NULL
DECLARE	@activeNow NVARCHAR(6) = N'No'
DECLARE @replaceNow NVARCHAR(3) = N'No'
DECLARE	@OpI_LoginPassword NVARCHAR(30) = N'abcd%12'
DECLARE @mustChange NVARCHAR(3) = N'No'					-- Yes or No
DECLARE	@passwordExpires NVARCHAR(3) = N'OFF'			-- ON or OFF
DECLARE	@checkPolicy NVARCHAR(3) = N'OFF'				-- ON or OFF
DECLARE	@OpI_LoginWindows NVARCHAR(9) = NULL
DECLARE	@roleName NVARCHAR(max) = NULL
DECLARE	@with NVARCHAR(max) = NULL
DECLARE	@query NVARCHAR(max) = NULL

SET		@OpI_LoginName=N'ProgramManagement2';
SET		@activeNow = N'Yes'
SET		@replaceNow = N'No'
SET		@OpI_LoginWindows=N'SQLServer';					-- WINDOWS or SQLServer
SET			@OpI_LoginPassword=N'abcd%12';				-- For SQLServer; WINDOWS Login takes from Windows security
SET			@mustChange = N'No'							-- For SQLServer; Yes or No
SET			@passwordExpires = N'OFF'					-- For SQLServer; ON or OFF
SET			@checkPolicy = N'OFF'						-- For SQLServer; ON or OFF
SET		@roleName = N'OpIRoleSvrManager'				-- OpIRoleSvrSuper, OpIRoleSvrManager, OpIRoleSvrDataOwner, OpIRoleSvrClient

IF @activeNow = N'Yes'
BEGIN
	IF @replaceNow = N'Yes' 
	BEGIN 
		SET @query = 
		N'IF EXISTS (SELECT[sys].[sql_logins].[name], [sys].[sql_logins].[type] '
		+ N'	FROM [sys].[sql_logins]'
		+ N'	WHERE [type] IN (N''U'', N''S'') AND [name] = ''' + @OpI_LoginName + N''') '
		+ N'DROP LOGIN ' + @OpI_LoginName + N';';  EXEC sp_executesql @query;
	END

	SET	@with = NULL
	IF	(@OpI_LoginWindows=N'SQLServer')
	BEGIN
		SET @with = ' WITH PASSWORD = N''' + @OpI_LoginPassword + N''''
		IF @mustChange = 'Yes' SET @with = @with + ', MUSTCHANGE'
		SET @with = @with + N', CHECK_EXPIRATION = ' + @passwordExpires
		SET @with = @with + N', CHECK_POLICY = ' + @checkPolicy
	END
	IF	( @OpI_LoginWindows = N'WINDOWS' )	
		SET @with=N' FROM WINDOWS'

	IF NOT EXISTS (SELECT [sys].[sql_logins].[name], [sys].[sql_logins].[type] 
		FROM [sys].[sql_logins] 
		WHERE [type] IN (N'U', N'S') AND [name] = @OpI_LoginName) 
	BEGIN 
		SET @query = N'CREATE LOGIN  [' + @OpI_LoginName + ']' + @with +  N';'; EXEC sp_executesql @query;
	END;
	
	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;

	/* Add membership to OpI Fixed-Role Membership Role if it exists */
	SET @query = N'IF EXISTS(SELECT [sys].[server_principals].[name], [sys].[server_principals].[type] ' +
	N'	FROM [sys].[server_principals] ' +
    N'	WHERE [type] IN (N''R'') AND [name]= ''' + @roleName + N'Fixed' + N''') ' +
	N'ALTER SERVER ROLE ' + @roleName + N'Fixed' + N' ADD MEMBER ' + @OpI_LoginName + ';'; EXEC sp_executesql @query;
END
GO